.. This README is meant for consumption by humans and PyPI. PyPI can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on PyPI or github. It is a comment.

.. image:: https://github.com/IMIO/collective.plausible/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/IMIO/collective.plausible/actions/workflows/plone-package.yml

.. image:: https://codecov.io/gh/IMIO/collective.plausible/graph/badge.svg?token=28881WG157
    :target: https://codecov.io/gh/IMIO/collective.plausible

.. image:: https://img.shields.io/pypi/v/collective.plausible.svg
    :target: https://pypi.python.org/pypi/collective.plausible/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/collective.plausible.svg
    :target: https://pypi.python.org/pypi/collective.plausible
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/collective.plausible.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/collective.plausible.svg
    :target: https://pypi.python.org/pypi/collective.plausible/
    :alt: License


====================
collective.plausible
====================

Plausible integration into Plone 5 and Plone 6 classic UI

Features
--------

- Plausible browserview




Documentation
-------------

Full documentation for end users can be found in the "docs" folder.


Translations
------------

This product has been translated into

- English
- French


Installation
------------

Install collective.plausible by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.plausible


and then running ``bin/buildout``


Authors
-------

iMio


Contributors
------------

- Rémi Dubois <remi.dubois@imio.be>
- Christophe Boulanger <christophe.boulanger@imio.be>


Contribute
----------

- Issue Tracker: https://github.com/IMIO/collective.plausible/issues
- Source Code: https://github.com/IMIO/collective.plausible
- Documentation: https://docs.plone.org/foo/bar


Support
-------

If you are having issues, please let us know by submitting an issue on the issue tracker.


License
-------

The project is licensed under the GPLv2.
